@@ -40,7 +40,6 @@
 #include <math.h>
 #include <string.h>
 #include <ctype.h>
-#include <stdlib.h>
 
 #include "hy_string_buffer.h"
 #include "dataset.h"
@@ -217,7 +216,7 @@ bool ReadNextNexusStatement (FileState& fState, FILE* f, _String& CurrentLine, l
 
     }
     // TODO 20170821: SLKP, this needs to be case sensitive
-    blank = blank.ChangeCase(kStringUpperCase);
+    blank.ChangeCaseInPlace(kStringUpperCase);
     if (newPos<CurrentLine.length()) {
         CurrentLine.Trim (newPos,kStringEnd);
     } else {
@@ -319,7 +318,6 @@ void    ProcessNexusTaxa (FileState& fState, long pos, FILE*f, _String& CurrentL
                     ReportWarning ( _String ("TAXALABELS provided ") &
                                     _String ((long)result.GetNames().lLength) &" species, whereas the NTAX statement promised:" &
                                     _String (speciesExpected) & ". HYPHY will use TAXALABELS count.");
-                     (key1);
                 }
                 done = true;
             }
@@ -702,7 +700,7 @@ void    ProcessNexusTrees (FileState& fState, long pos, FILE*f, _String& Current
         _StringBuffer revisedTreeString (128L);
       
       // TODO SLKP 20170621: looks like this is a generic Newick parser; why duplicate it here?
-        for (long i=0; i<file_tree_string->length(); ++i) {
+        for (i=0; i<file_tree_string->length(); ++i) {
             char    cc = file_tree_string->char_at (i);
 
             switch (cc) {
