@@ -38,7 +38,6 @@
  */
 
 #include <math.h>
-#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -177,7 +176,7 @@ void        PopulateArraysForASimpleFormula (_SimpleList& vars, _SimpleFormulaDa
                 }
             }
         });
-    } catch (const _String e) {
+    } catch (const _String& e) {
         HandleApplicationError (e, true);
     }
 }
@@ -224,7 +223,7 @@ long       ExecuteFormula (_Formula*f , _Formula* f2, long code, long reference,
         if (code == HY_FORMULA_VARIABLE_VALUE_ASSIGNMENT) {
             // copy by value or by reference?
             //formulaValue->AddAReference();
-            LocateVar (reference)->SetValue (formulaValue);
+            LocateVar (reference)->SetValue (formulaValue, true,true,NULL);
             return 1;
         }
 
@@ -232,7 +231,7 @@ long       ExecuteFormula (_Formula*f , _Formula* f2, long code, long reference,
             _hyExecutionContext localContext (nameSpace);
             _Variable * theV = f->Dereference(assignment_type == kStringGlobalDeference, &localContext);
             if (theV) {
-                theV->SetValue (formulaValue);
+                theV->SetValue (formulaValue, true,true,NULL);
             } else {
                 return 0;
             }
@@ -305,6 +304,7 @@ long       ExecuteFormula (_Formula*f , _Formula* f2, long code, long reference,
 
     if ( code== HY_FORMULA_FORMULA_FORMULA_ASSIGNMENT || code== HY_FORMULA_FORMULA_VALUE_ASSIGNMENT || code == HY_FORMULA_FORMULA_VALUE_INCREMENT) {
         _Formula newF;
+        HBLObjectRef rhsValue = nil;
 
         if (f2->IsEmpty()) {
             HandleApplicationError ("Empty RHS in an assignment.");
@@ -314,7 +314,10 @@ long       ExecuteFormula (_Formula*f , _Formula* f2, long code, long reference,
         if (code == HY_FORMULA_FORMULA_FORMULA_ASSIGNMENT) {
             newF.DuplicateReference(f2);
         } else {
-            newF.theFormula.AppendNewInstance(new _Operation((HBLObjectRef)f2->Compute(0, nameSpace)->makeDynamic()));
+            //newF.theFormula.AppendNewInstance(new _Operation((HBLObjectRef)f2->Compute(0, nameSpace)->makeDynamic()));
+            rhsValue = (HBLObjectRef)f2->Compute(0, nameSpace)->makeDynamic();
+            //rhsValue->makeDynamic();
+            //newF.theFormula.AppendNewInstance(new _Operation(rhs_value));
         }
 
         long stackD = -1L,
@@ -388,7 +391,12 @@ long       ExecuteFormula (_Formula*f , _Formula* f2, long code, long reference,
 
             if (mmx->CheckCoordinates (hC,vC)) {
                 if (!ANALYTIC_COMPUTATION_FLAG) {
-                    mmx->MStore (hC, vC, newF, (code==HY_FORMULA_FORMULA_VALUE_INCREMENT)?HY_OP_CODE_ADD:HY_OP_CODE_NONE);
+                    if (rhsValue) {
+                        mmx->MStore (hC, vC, rhsValue, (code==HY_FORMULA_FORMULA_VALUE_INCREMENT)?HY_OP_CODE_ADD:HY_OP_CODE_NONE);
+                        DeleteObject (rhsValue);
+                    } else {
+                        mmx->MStore (hC, vC, newF, (code==HY_FORMULA_FORMULA_VALUE_INCREMENT)?HY_OP_CODE_ADD:HY_OP_CODE_NONE);
+                    }
                 } else {
                     HBLObjectRef newP = newF.ConstructPolynomial();
                     if (!newP) {
@@ -400,7 +408,12 @@ long       ExecuteFormula (_Formula*f , _Formula* f2, long code, long reference,
                 mmx->CheckIfSparseEnough();
             }
         } else if (mma) { // Associative array LHS
-            mma->MStore (coordMx, newF.Compute(), true, (code==HY_FORMULA_FORMULA_VALUE_INCREMENT)?HY_OP_CODE_ADD:HY_OP_CODE_NONE);
+            if (rhsValue) {
+                mma->MStore (coordMx, rhsValue, true, (code==HY_FORMULA_FORMULA_VALUE_INCREMENT)?HY_OP_CODE_ADD:HY_OP_CODE_NONE);
+                DeleteObject (rhsValue);
+            }
+            else
+                mma->MStore (coordMx, newF.Compute(), true, (code==HY_FORMULA_FORMULA_VALUE_INCREMENT)?HY_OP_CODE_ADD:HY_OP_CODE_NONE);
         }
 
         return 1;
@@ -572,9 +585,9 @@ long _parserHelperHandleInlineAssignmentCases (_String& s, _FormulaParsingContex
         if (twoToken && s.get_char(i-1) == '+') {
             _List arg;
             arg <<  varObj;
-            theV->SetValue(theV->Compute()->ExecuteSingleOp(HY_OP_CODE_ADD,&arg));
+            theV->SetValue(theV->Compute()->ExecuteSingleOp(HY_OP_CODE_ADD,&arg), true,true,NULL);
         } else {
-            theV->SetValue(varObj);
+            theV->SetValue(varObj, true,true,NULL);
         }
     } else {
         theV->SetFormula (newF);
@@ -599,6 +612,14 @@ void        _parse_new_level (long & level, _List & operations, _List& operands,
 }
 
 
+//#define _TRACK_PARSE_COUNTS
+
+#ifdef _TRACK_PARSE_COUNTS
+    unsigned long parse_counter = 0UL;
+    _List       _parse_counter_list;
+    _AVLListX   _parse_counter_dict (&_parse_counter_list);
+#endif
+
 
 //__________________________________________________________________________________
 long        Parse (_Formula* f, _String& s, _FormulaParsingContext& parsingContext, _Formula* f2)
@@ -642,6 +663,32 @@ long        Parse (_Formula* f, _String& s, _FormulaParsingContext& parsingConte
 
 {
   //static bool inAssignment = false;
+    
+    static _String kEmptyDict   = "{}";
+    static _String kEmptyStringQuote = "\"\"";
+    if ( s == kEmptyDict) {
+        // SLKP 20200921: this is a common enough case that its worth shortcutting it
+        f->theFormula.AppendNewInstance (new _Operation (new _AssociativeList));
+        return HY_FORMULA_EXPRESSION;
+    }
+    if ( s == kEmptyStringQuote) {
+        // SLKP 20200921: this is a common enough case that its worth shortcutting it
+        f->theFormula.AppendNewInstance (new _Operation (new _FString));
+        return HY_FORMULA_EXPRESSION;
+    }
+    
+    // also check to see if the expression is a number
+    
+    if ( s.length () > 0 && s.length () < 30) {
+        hyFloat number;
+        int upto;
+        if (sscanf (s.get_str(), "%lf%n", &number, &upto) == 1) {
+            if (upto == s.length()) {
+                f->theFormula.AppendNewInstance (new _Operation (new _Constant (number)));
+                return HY_FORMULA_EXPRESSION;
+            }
+        }
+    }
 
     _List           operations,
                     operands,
@@ -663,6 +710,23 @@ long        Parse (_Formula* f, _String& s, _FormulaParsingContext& parsingConte
 
 
 
+#ifdef _TRACK_PARSE_COUNTS
+    if (s.nonempty()) {
+        _parse_counter_dict.UpdateValue (new _String (s), 1, 0);
+        parse_counter++;
+        if (parse_counter % 50000 == 0) {
+            printf ("\n>>%ld FORMULA PARSE<<\n", parse_counter);
+            for (AVLListXIteratorKeyValue variable_record : AVLListXIterator (&_parse_counter_dict)) {
+                if (variable_record.get_value() > parse_counter * 0.001) {
+                    printf ("%s: %ld\n", ((_String*)_parse_counter_dict.Retrieve (variable_record.get_index()))->get_str(), variable_record.get_value());
+                    
+                }
+            }
+            NLToConsole(); NLToConsole();
+        }
+    }
+#endif
+    
     long            level                 = -1;
     /* 04252006 mlevel = -1, */
     /* mcount = 0 ; */
@@ -1131,9 +1195,17 @@ long        Parse (_Formula* f, _String& s, _FormulaParsingContext& parsingConte
                 mergeMAccessLevel << level;
             } else {
                 if (levelData->lLength == 0 && f->IsEmpty()) {
-                   return HandleFormulaParsingError ("[..] must be preceded by an object to index ", parsingContext.errMsg(), s, i);
+                   // try JSON style matrix definition
+                   int     j       = s.ExtractEnclosedExpression (i,'[',']',fExtractRespectQuote | fExtractRespectEscape);
+                   _String matrixDef   (s,i,j);
+                   if (matrixDef.length() >= 2UL) {
+                       levelData->AppendNewInstance (new _Operation ( new _Matrix (matrixDef,false,parsingContext, true)));
+                       i = j;
+                       continue;
+                   } else {
+                       return HandleFormulaParsingError ("[..] must be preceded by an object to index ", parsingContext.errMsg(), s, i);
+                   }
                 }
-
                 if (levelData->lLength) {
                     //f->theFormula.AppendNewInstance((*levelData)[levelData->lLength-1]);
                     f->PushTerm(levelData->GetItem(levelData->lLength-1));
@@ -1573,14 +1645,14 @@ long        Parse (_Formula* f, _String& s, _FormulaParsingContext& parsingConte
 //__________________________________________________________________________________
 
 long     VerbosityLevel (void) {
-    checkParameter (VerbosityLevelString, verbosity_level, -1L);
+    if (force_verbosity_from_cli)  verbosity_level = 10L;
+    else verbosity_level = hy_env::EnvVariableGetNumber(hy_env::verbosity_level_string, -1.);
     return verbosity_level;
 }
 
 
 //__________________________________________________________________________________
-void  stashParameter (_String const& name, hyFloat v, bool set)
-{
+void  stashParameter (_String const& name, hyFloat v, bool set) {
     static  hyFloat stash = 0.0;
 
     long f = LocateVarByName (name);
@@ -1588,11 +1660,9 @@ void  stashParameter (_String const& name, hyFloat v, bool set)
         _Variable *thisV = FetchVar(f);
         if (set) {
             stash = thisV->Value();
-            _Constant dummy (v);
-            thisV->SetValue (&dummy);
+            thisV->SetValue (new _Constant (v),false,true,NULL);
         } else {
-            _Constant dummy (stash);
-            thisV->SetValue (&dummy);
+            thisV->SetValue (new _Constant (stash), false,true,NULL);
         }
     } else if (set) {
         stash = v;
@@ -1613,7 +1683,7 @@ void  setParameter (_String const & name, hyFloat def, _String* namespc)
             _Variable cornholio(name);
             setParameter (name,def);
         } else {
-            FetchVar(f)->SetValue(new _Constant (def), false);
+            FetchVar(f)->SetValue(new _Constant (def), false,true,NULL);
         }
     }
 }
@@ -1631,7 +1701,7 @@ void  setParameter (_String const& name, HBLObjectRef def, _String* namespc, boo
             _Variable cornholio(name);
             setParameter (name,def,nil, dup);
         } else {
-            FetchVar(f)->SetValue(def,dup);
+            FetchVar(f)->SetValue(def,dup,true,NULL);
         }
     }
 }
